@@ -15,7 +15,7 @@
 
 """Python wrapping of ScatteringData class.
 
-See the online ObjCryst++ documentation (http://vincefn.net/ObjCryst/).
+See the online ObjCryst++ documentation (https://objcryst.readthedocs.io).
 """
 
 __all__ = ["ScatteringData"]
