@@ -15,7 +15,7 @@
 
 """Python wrapping of ScatteringPowerSphere.h
 
-See the online ObjCryst++ documentation (http://vincefn.net/ObjCryst/).
+See the online ObjCryst++ documentation (https://objcryst.readthedocs.io).
 """
 
 __all__ = ["ScatteringPowerSphere"]
